//Copyright (C) 2000 Microsoft Corporation.  All rights reserved.

//This source code is intended only as a supplement to Microsoft
//Development Tools and/or on-line documentation.  See these other
//materials for detailed information regarding Microsoft code samples.

//THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
//KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
//PARTICULAR PURPOSE.


namespace SdiBaseSimple
{
	using System;
	using System.Drawing;
	using System.Drawing.Printing;

	using System.Collections;
	using System.ComponentModel;
	using System.Windows.Forms;


	/// <summary>
    /// <p>
	/// Main form for Sdi application.
    /// Extend main form for Sdi app from this class.
    /// Modify the extended form in the GUI designer.
	/// </summary>
	public class SdiMainForm : System.Windows.Forms.Form
	{
        private SdiApplicationContext m_context;
		
		/// <summary> 
		///    Required designer variable.
		/// </summary>
		/// 
		private System.ComponentModel.IContainer sdiComponents;

        /// <summary>
        /// Default constructor, needed for designer.
        /// </summary>
        public SdiMainForm()
        {
            SdiInitializeComponent();
        }

        /// <summary>
        ///    Constructor with context.
        /// <p>
        /// Must be called by extended class. This constructor sets the applicatoin
        /// context and sets the form as the main form for the application context.
        /// </summary>
        public SdiMainForm(SdiApplicationContext ctx)
        {
            // Required for Win Form Designer support
            // Change name so that base class initialization
            // is not overriden by extended class.
            SdiInitializeComponent();

            m_context = ctx;

            Context.MainForm = this;
        }

		/// <summary>
		///    Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (sdiComponents != null) 
				{
					sdiComponents.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		
		private void SdiInitializeComponent()
		{
			this.sdiComponents = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(SdiMainForm));
			this.SuspendLayout();
			// 
			// SdiMainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.BackColor = System.Drawing.Color.Firebrick;
			this.ClientSize = new System.Drawing.Size(432, 425);
			this.Name = "SdiMainForm";
			this.Text = "SDI sample Application";
			this.ResumeLayout(false);
	
		}

        /// <summary>
        /// Property that returns the context for the application.
        /// <p>
        /// The context for the entire application is actually a private member
        /// variable in the main form base class.
        /// </summary>
		public SdiApplicationContext Context 
		{
			get 
			{
				return m_context;
			}
		}

	}
}
